@@ -2,10 +2,9 @@ import random
 
 import rabbyt
 from rabbyt import lerp, wrap
-
 import pygame
-
-pygame.init()
+import os.path
+rabbyt.data_directory = os.path.dirname(__file__)
 
 rabbyt.init_display((640, 480))
 
@@ -15,11 +14,11 @@ sprites = []
 r = lambda: random.random()-.5
 
 for i in range(2400):
-    s = rabbyt.Sprite()
+    s = rabbyt.Sprite("rounded_square.png")
     s.rgba = lerp((.5,.2,1,.2), (0,.8,0,.6), dt=3000*r()+2000, extend="reverse")
 
     s.x = wrap([-320,320], lerp(r()*640, r()*640, dt=2000, extend="extrapolate"))
-    s.y = wrap([-240,240], lerp(r()*640, r()*480, dt=2000, extend="extrapolate"))
+    s.y = wrap([-240,240], lerp(r()*480, r()*480, dt=2000, extend="extrapolate"))
 
     s.scale = lerp(.1, 1, dt=1000*r()+750, extend="reverse")
 
@@ -27,6 +26,8 @@ for i in range(2400):
 
     sprites.append(s)
 
+print "Drawing 2400 sprites..."
+
 c = pygame.time.Clock()
 last_fps = 0
 while True:
