@@ -2,7 +2,6 @@
 Rabbyt is a fast 2d sprite library for Python.
 """
 
-
 __credits__ = (
 """
 Copyright (C) 2007  Matthew Marshall
@@ -23,11 +22,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 import heapq
+import os.path
 
-from _rabbyt import *
+from rabbyt._rabbyt import *
 
 extend_types = dict(constant=1, extrapolate=2, repeat=3, reverse=4)
 
@@ -45,6 +45,27 @@ def _handle_time_args(startt, endt, dt):
 
 
 def lerp(start, end, startt=None, endt=None, dt=None, extend="constant"):
+    """
+    lerp(start, end, [startt,] [endt,] [dt,] [extend])
+
+    Linearly interpolates between start and end as time moves from start to
+    endt.
+
+    startt is the time to start.  It defaults to rabbyt.get_time().
+
+    To specify the ending time, use either endt, which is the absolute time,
+    or dt, which is relative from startt.
+
+    For example, all of the following are equivalent:
+
+        lerp(0, 1, rabbyt.get_time(), rabbyt.get_time()+1000)
+        lerp(0, 1, rabbyt.get_time(), dt=1000)
+        lerp(0, 1, dt=1000)
+
+    extend is a string defining what to do before startt and after endt.
+    Possible values are "constant", "extrapolate", "repeat", "reverse".  The
+    default is "constant".  Check out the extend_modes.py example for more info.
+    """
     extend = extend_types[extend]
 
     startt, endt = _handle_time_args(startt, endt, dt)
@@ -129,16 +150,22 @@ def init_display(size=(640, 480)):
     This function depends on pygame.
     """
     import pygame
+    pygame.init()
     pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
     set_viewport(size)
     set_default_attribs()
 
 _texture_cache = {}
 
+data_directory = ""
+
 def pygame_load_texture(filename):
     if filename not in _texture_cache:
         import pygame
-        img = pygame.image.load(filename)
+        if os.path.exists(filename):
+            img = pygame.image.load(filename)
+        else:
+            img = pygame.image.load(os.path.join(data_directory, filename))
         data, size = pygame.image.tostring(img, 'RGBA', True), img.get_size()
         _texture_cache[filename] = load_texture(data, size), size
     return _texture_cache[filename]
